@@ -10,7 +10,7 @@ from typing import Dict, List, Optional
 from ycontract import contract
 
 from exclock.sound_player import Player
-from exclock.util import get_real_sound_filename, get_time_delta_from_str, notify_all_term
+from exclock.util import get_real_sound_filename, get_time_delta_from_str, notify_all
 
 DEFAULT_TITLE = 'ExClock'
 
@@ -83,7 +83,7 @@ class ClockTimer:
         for i, (sec, sound) in enumerate(sounds.items()):
             spend_sec = secs[i] - (0 if i == 0 else secs[i - 1])
             message = inner_str(sound.message, {'count': count})
-            notify_all_term(
+            notify_all(
                 title=self.title,
                 message=message,
                 spend_sec=spend_sec,
